@@ -1,5 +1,3 @@
-import { clamp, omit } from 'lodash';
-
 import {
   DataQuery,
   DataSourceInstanceSettings,
@@ -31,7 +29,6 @@ import {
   AlertDataQuery,
   AlertQuery,
   Annotations,
-  GrafanaAlertStateDecision,
   GrafanaNotificationSettings,
   GrafanaRuleDefinition,
   Labels,
@@ -42,6 +39,8 @@ import {
 } from 'app/types/unified-alerting-dto';
 
 import { EvalFunction } from '../../state/alertDef';
+import { getDefaultFormValues } from '../rule-editor/formDefaults';
+import { normalizeDefaultAnnotations } from '../rule-editor/formProcessing';
 import {
   AlertManagerManualRouting,
   ContactPoint,
@@ -51,8 +50,7 @@ import {
   SimplifiedEditor,
 } from '../types/rule-form';
 
-import { getRulesAccess } from './access-control';
-import { Annotation, defaultAnnotations } from './constants';
+import { Annotation } from './constants';
 import {
   DataSourceType,
   GRAFANA_RULES_SOURCE_NAME,
@@ -60,92 +58,14 @@ import {
   isGrafanaRulesSource,
 } from './datasource';
 import { arrayToRecord, recordToArray } from './misc';
-import {
-  isAlertingRulerRule,
-  isGrafanaAlertingRuleByType,
-  isGrafanaRecordingRule,
-  isGrafanaRecordingRuleByType,
-  isGrafanaRulerRule,
-  isRecordingRulerRule,
-} from './rules';
-import { formatPrometheusDuration, parseInterval, safeParsePrometheusDuration } from './time';
+import { isGrafanaAlertingRuleByType, isGrafanaRecordingRuleByType, rulerRuleType } from './rules';
+import { parseInterval } from './time';
 
 export type PromOrLokiQuery = PromQuery | LokiQuery;
 
 export const MANUAL_ROUTING_KEY = 'grafana.alerting.manualRouting';
 export const SIMPLIFIED_QUERY_EDITOR_KEY = 'grafana.alerting.simplifiedQueryEditor';
 
-// even if the min interval is < 1m we should default to 1m, but allow arbitrary values for minInterval > 1m
-const GROUP_EVALUATION_MIN_INTERVAL_MS = safeParsePrometheusDuration(config.unifiedAlerting?.minInterval ?? '10s');
-const GROUP_EVALUATION_INTERVAL_LOWER_BOUND = safeParsePrometheusDuration('1m');
-const GROUP_EVALUATION_INTERVAL_UPPER_BOUND = Infinity;
-
-export const DEFAULT_GROUP_EVALUATION_INTERVAL = formatPrometheusDuration(
-  clamp(GROUP_EVALUATION_MIN_INTERVAL_MS, GROUP_EVALUATION_INTERVAL_LOWER_BOUND, GROUP_EVALUATION_INTERVAL_UPPER_BOUND)
-);
-
-export const getDefaultFormValues = (): RuleFormValues => {
-  const { canCreateGrafanaRules, canCreateCloudRules } = getRulesAccess();
-
-  return Object.freeze({
-    name: '',
-    uid: '',
-    labels: [{ key: '', value: '' }],
-    annotations: defaultAnnotations,
-    dataSourceName: GRAFANA_RULES_SOURCE_NAME, // let's use Grafana-managed alert rule by default
-    type: canCreateGrafanaRules ? RuleFormType.grafana : canCreateCloudRules ? RuleFormType.cloudAlerting : undefined, // viewers can't create prom alerts
-    group: '',
-
-    // grafana
-    folder: undefined,
-    queries: [],
-    recordingRulesQueries: [],
-    condition: '',
-    noDataState: GrafanaAlertStateDecision.NoData,
-    execErrState: GrafanaAlertStateDecision.Error,
-    evaluateFor: DEFAULT_GROUP_EVALUATION_INTERVAL,
-    evaluateEvery: DEFAULT_GROUP_EVALUATION_INTERVAL,
-    manualRouting: getDefautManualRouting(), // we default to true if the feature toggle is enabled and the user hasn't set local storage to false
-    contactPoints: {},
-    overrideGrouping: false,
-    overrideTimings: false,
-    muteTimeIntervals: [],
-    editorSettings: getDefaultEditorSettings(),
-
-    // cortex / loki
-    namespace: '',
-    expression: '',
-    forTime: 1,
-    forTimeUnit: 'm',
-  });
-};
-
-export const getDefautManualRouting = () => {
-  // first check if feature toggle for simplified routing is enabled
-  const simplifiedRoutingToggleEnabled = config.featureToggles.alertingSimplifiedRouting ?? false;
-  if (!simplifiedRoutingToggleEnabled) {
-    return false;
-  }
-  //then, check in local storage if the user has enabled simplified routing
-  // if it's not set, we'll default to true
-  const manualRouting = localStorage.getItem(MANUAL_ROUTING_KEY);
-  return manualRouting !== 'false';
-};
-
-function getDefaultEditorSettings() {
-  const editorSettingsEnabled = config.featureToggles.alertingQueryAndExpressionsStepMode ?? false;
-  if (!editorSettingsEnabled) {
-    return undefined;
-  }
-  //then, check in local storage if the user has saved last rule with sections simplified
-  const queryEditorSettings = localStorage.getItem(SIMPLIFIED_QUERY_EDITOR_KEY);
-  const notificationStepSettings = localStorage.getItem(MANUAL_ROUTING_KEY);
-  return {
-    simplifiedQueryEditor: queryEditorSettings !== 'false',
-    simplifiedNotificationEditor: notificationStepSettings !== 'false',
-  };
-}
-
 export function formValuesToRulerRuleDTO(values: RuleFormValues): RulerRuleDTO {
   const { name, expression, forTime, forTimeUnit, keepFiringForTime, keepFiringForTimeUnit, type } = values;
 
@@ -184,26 +104,6 @@ export function listifyLabelsOrAnnotations(item: Labels | Annotations | undefine
   return list;
 }
 
-//make sure default annotations are always shown in order even if empty
-export function normalizeDefaultAnnotations(annotations: KVObject[]) {
-  const orderedAnnotations = [...annotations];
-  const defaultAnnotationKeys = defaultAnnotations.map((annotation) => annotation.key);
-
-  defaultAnnotationKeys.forEach((defaultAnnotationKey, index) => {
-    const fieldIndex = orderedAnnotations.findIndex((field) => field.key === defaultAnnotationKey);
-
-    if (fieldIndex === -1) {
-      //add the default annotation if abstent
-      const emptyValue = { key: defaultAnnotationKey, value: '' };
-      orderedAnnotations.splice(index, 0, emptyValue);
-    } else if (fieldIndex !== index) {
-      //move it to the correct position if present
-      orderedAnnotations.splice(index, 0, orderedAnnotations.splice(fieldIndex, 1)[0]);
-    }
-  });
-  return orderedAnnotations;
-}
-
 export function getNotificationSettingsForDTO(
   manualRouting: boolean,
   contactPoints?: AlertManagerManualRouting
@@ -368,7 +268,7 @@ export function rulerRuleToFormValues(ruleWithLocation: RuleWithLocation): RuleF
   const defaultFormValues = getDefaultFormValues();
   if (isGrafanaRulesSource(ruleSourceName)) {
     // GRAFANA-MANAGED RULES
-    if (isGrafanaRecordingRule(rule)) {
+    if (rulerRuleType.grafana.recordingRule(rule)) {
       // grafana recording rule
       const ga = rule.grafana_alert;
       return {
@@ -385,7 +285,7 @@ export function rulerRuleToFormValues(ruleWithLocation: RuleWithLocation): RuleF
         isPaused: ga.is_paused,
         metric: ga.record?.metric,
       };
-    } else if (isGrafanaRulerRule(rule)) {
+    } else if (rulerRuleType.grafana.rule(rule)) {
       // grafana alerting rule
       const ga = rule.grafana_alert;
       const routingSettings: AlertManagerManualRouting | undefined = getContactPointsFromDTO(ga);
@@ -419,7 +319,7 @@ export function rulerRuleToFormValues(ruleWithLocation: RuleWithLocation): RuleF
     }
   } else {
     // DATASOURCE-MANAGED RULES
-    if (isAlertingRulerRule(rule)) {
+    if (rulerRuleType.dataSource.alertingRule(rule)) {
       const datasourceUid = getDataSourceSrv().getInstanceSettings(ruleSourceName)?.uid ?? '';
 
       const defaultQuery = {
@@ -447,7 +347,7 @@ export function rulerRuleToFormValues(ruleWithLocation: RuleWithLocation): RuleF
         namespace,
         group: group.name,
       };
-    } else if (isRecordingRulerRule(rule)) {
+    } else if (rulerRuleType.dataSource.recordingRule(rule)) {
       const recordingRuleValues = recordingRulerRuleToRuleForm(rule);
 
       return {
@@ -902,21 +802,6 @@ export function isPromOrLokiQuery(model: AlertDataQuery): model is PromOrLokiQue
   return 'expr' in model;
 }
 
-// the backend will always execute "hidden" queries, so we have no choice but to remove the property in the front-end
-// to avoid confusion. The query editor shows them as "disabled" and that's a different semantic meaning.
-// furthermore the "AlertingQueryRunner" calls `filterQuery` on each data source and those will skip running queries that are "hidden"."
-// It seems like we have no choice but to act like "hidden" queries don't exist in alerting.
-export const ignoreHiddenQueries = (ruleDefinition: RuleFormValues): RuleFormValues => {
-  return {
-    ...ruleDefinition,
-    queries: ruleDefinition.queries?.map((query) => omit(query, 'model.hide')),
-  };
-};
-
-export function formValuesFromExistingRule(rule: RuleWithLocation<RulerRuleDTO>) {
-  return ignoreHiddenQueries(rulerRuleToFormValues(rule));
-}
-
 export function getInstantFromDataQuery(model: AlertDataQuery, type: string): boolean | undefined {
   // if the datasource is not prometheus or loki, instant is defined in the model or defaults to undefined
   if (type !== DataSourceType.Prometheus && type !== DataSourceType.Loki) {
