@@ -3,6 +3,7 @@ import userEvent from '@testing-library/user-event';
 import { TestProvider } from 'test/helpers/TestProvider';
 
 import { PluginType } from '@grafana/data';
+import { locationService } from '@grafana/runtime';
 import { contextSrv } from 'app/core/core';
 import { getCatalogPluginMock, getPluginsStateMock } from 'app/features/plugins/admin/__mocks__';
 import { CatalogPlugin } from 'app/features/plugins/admin/types';
@@ -17,7 +18,8 @@ jest.mock('@grafana/runtime', () => ({
   useChromeHeaderHeight: jest.fn(),
 }));
 
-const renderPage = (plugins: CatalogPlugin[] = []): RenderResult => {
+const renderPage = (plugins: CatalogPlugin[] = [], path = '/add-new-connection'): RenderResult => {
+  locationService.push(path);
   return render(
     <TestProvider storeState={{ plugins: getPluginsStateMock(plugins) }}>
       <AddNewConnection />
@@ -31,7 +33,7 @@ const mockCatalogDataSourcePlugin = getCatalogPluginMock({
   id: 'sample-data-source',
 });
 
-describe('Angular badge', () => {
+describe('Badges', () => {
   test('does not show angular badge for non-angular plugins', async () => {
     renderPage([
       getCatalogPluginMock({
@@ -61,6 +63,28 @@ describe('Angular badge', () => {
     });
     expect(screen.queryByText('Angular')).toBeInTheDocument();
   });
+
+  test('shows enterprise and deprecated badges for plugins', async () => {
+    renderPage([
+      getCatalogPluginMock({
+        id: 'test-plugin',
+        name: 'test Plugin',
+        type: PluginType.datasource,
+        isEnterprise: true,
+      }),
+      getCatalogPluginMock({
+        id: 'test2-plugin',
+        name: 'test2 Plugin',
+        type: PluginType.datasource,
+        isDeprecated: true,
+      }),
+    ]);
+    await waitFor(() => {
+      expect(screen.queryByText('test Plugin')).toBeInTheDocument();
+    });
+    expect(screen.queryByText('Enterprise')).toBeVisible();
+    expect(screen.queryByText('Deprecated')).toBeVisible();
+  });
 });
 
 describe('Add new connection', () => {
@@ -81,20 +105,57 @@ describe('Add new connection', () => {
 
     expect(await screen.findByText('Sample data source')).toBeVisible();
   });
+  test('should list plugins with update when filtering by update', async () => {
+    const { queryByText } = renderPage(
+      [
+        getCatalogPluginMock({
+          id: 'plugin-1',
+          name: 'Plugin 1',
+          isInstalled: true,
+          hasUpdate: true,
+          type: PluginType.datasource,
+        }),
+        getCatalogPluginMock({ id: 'plugin-2', name: 'Plugin 2', isInstalled: false }),
+        getCatalogPluginMock({
+          id: 'plugin-3',
+          name: 'Plugin 3',
+          isInstalled: true,
+          hasUpdate: true,
+          type: PluginType.datasource,
+        }),
+        getCatalogPluginMock({ id: 'plugin-4', name: 'Plugin 4', isInstalled: true, isCore: true }),
+      ],
+      '/add-new-connection?filterBy=has-update'
+    );
+
+    await waitFor(() => expect(queryByText('Plugin 1')).toBeInTheDocument());
+    expect(queryByText('Plugin 3')).toBeInTheDocument();
+
+    expect(queryByText('Plugin 2')).not.toBeInTheDocument();
+    expect(queryByText('Plugin 4')).not.toBeInTheDocument();
+  });
 
   test('renders card if search term matches', async () => {
-    renderPage([getCatalogPluginMock(), mockCatalogDataSourcePlugin]);
-    const searchField = await screen.findByRole('textbox');
+    renderPage(
+      [
+        getCatalogPluginMock({ type: PluginType.datasource, id: 'test1', name: 'test33' }),
+        getCatalogPluginMock({ id: 'test2', type: PluginType.datasource, name: 'querymatches' }),
+      ],
+      '/add-new-connection?filterBy=all&sortBy=nameAsc&search=querymatches'
+    );
+    expect(await screen.findByText('querymatches')).toBeVisible();
+  });
 
-    await userEvent.type(searchField, 'ampl');
-    expect(await screen.findByText('Sample data source')).toBeVisible();
+  test('renders no results if search term does not match', async () => {
+    renderPage(
+      [
+        getCatalogPluginMock({ type: PluginType.datasource, id: 'test1', name: 'test33' }),
+        getCatalogPluginMock({ id: 'test2', type: PluginType.datasource, name: 'querymatches' }),
+      ],
+      '/add-new-connection?filterBy=all&sortBy=nameAsc&search=dfvdfv'
+    );
 
-    await userEvent.clear(searchField);
-    await userEvent.type(searchField, 'cramp');
-    expect(screen.queryByText('No results matching your query were found')).toBeInTheDocument();
-
-    await userEvent.clear(searchField);
-    expect(await screen.findByText('Sample data source')).toBeVisible();
+    expect(await screen.findByText('No results matching your query were found')).toBeVisible();
   });
 
   test('shows a "No access" modal if the user does not have permissions to create datasources', async () => {
