@@ -1,6 +1,7 @@
 import { map } from 'lodash';
 
-import { SelectableValue, VariableWithMultiSupport } from '@grafana/data';
+import { ScopedVars, SelectableValue, VariableWithMultiSupport } from '@grafana/data';
+import { TemplateSrv, VariableInterpolation } from '@grafana/runtime';
 
 import { AzureMonitorOption, VariableOptionGroup } from '../types';
 
@@ -72,3 +73,47 @@ export function interpolateVariable(
   });
   return quotedValues.join(',');
 }
+
+export function replaceTemplateVariables<T extends { [K in keyof T]: string }>(
+  templateSrv: TemplateSrv,
+  query: T,
+  scopedVars?: ScopedVars
+) {
+  const workingQueries: Array<{ [K in keyof T]: string }> = [{ ...query }];
+  const keys = Object.keys(query) as Array<keyof T>;
+  keys.forEach((key) => {
+    const rawValue = workingQueries[0][key];
+    let interpolated: VariableInterpolation[] = [];
+    const replaced = templateSrv.replace(rawValue, scopedVars, 'raw', interpolated);
+    if (interpolated.length > 0) {
+      for (const variable of interpolated) {
+        if (variable.found === false) {
+          continue;
+        }
+        if (variable.value.includes(',')) {
+          const multiple = variable.value.split(',');
+          const currentQueries = [...workingQueries];
+          multiple.forEach((value, i) => {
+            currentQueries.forEach((q) => {
+              if (i === 0) {
+                q[key] = rawValue.replace(variable.match, value);
+              } else {
+                workingQueries.push({ ...q, [key]: rawValue.replace(variable.match, value) });
+              }
+            });
+          });
+        } else {
+          workingQueries.forEach((q) => {
+            q[key] = replaced;
+          });
+        }
+      }
+    } else {
+      workingQueries.forEach((q) => {
+        q[key] = replaced;
+      });
+    }
+  });
+
+  return workingQueries;
+}
